### Generate milestone name

To generate milestone name, use genereate-milestone-name task

example:

```bash
inv generate-milestone-name 01-01-2018 07-01-2018
```

First argument is start date, second is end date.
